@@ -1,4 +1,4 @@
-//! Resolve addresses to f function: (), file: (), line: ()  function: (), file: (), line: ()  function: (), file: (), line: () unction names, and to file name and line number
+//! Resolve addresses to function names, and to file name and line number
 //! information, with the help of a PDB file. Inline stacks are supported.
 //!
 //! The API of this crate is intended to be similar to the API of the
@@ -229,7 +229,7 @@ impl<'a, 's, 't> Context<'a, 's, 't> {
                 ..
             })) = symbol.parse()
             {
-                let start_rva = match offset.to_rva(&address_map) {
+                let start_rva = match offset.to_rva(address_map) {
                     Some(rva) => rva.0,
                     None => continue,
                 };
@@ -250,7 +250,7 @@ impl<'a, 's, 't> Context<'a, 's, 't> {
                     if proc.len == 0 {
                         continue;
                     }
-                    let start_rva = match proc.offset.to_rva(&address_map) {
+                    let start_rva = match proc.offset.to_rva(address_map) {
                         Some(rva) => rva.0,
                         None => continue,
                     };
@@ -371,7 +371,7 @@ impl<'a, 's, 't> Context<'a, 's, 't> {
             Some(index) => {
                 let line_info = &lines[index];
                 (
-                    self.resolve_filename(&line_program, line_info.file_index),
+                    self.resolve_filename(line_program, line_info.file_index),
                     Some(line_info.line_start),
                 )
             }
@@ -415,10 +415,9 @@ impl<'a, 's, 't> Context<'a, 's, 't> {
                 Ok(index) => (&inline_ranges[index], &inline_ranges[index + 1..]),
                 Err(_) => break,
             };
-            let function = match self.get_inline_name(inline_range.inlinee) {
-                Some(name) => Some(name.deref().clone()),
-                None => None,
-            };
+            let function = self
+                .get_inline_name(inline_range.inlinee)
+                .map(|name| name.deref().clone());
             let file = inline_range
                 .file_index
                 .and_then(|file_index| self.resolve_filename(line_program, file_index));
@@ -514,15 +513,9 @@ impl<'a, 's, 't> Context<'a, 's, 't> {
         name: &RawString<'a>,
         proc: &ProcedureSymbolInfo,
     ) -> Option<String> {
-        let mut formatted_function_name = String::new();
         self.type_formatter
-            .write_function(
-                &mut formatted_function_name,
-                &name.to_string(),
-                proc.type_index,
-            )
-            .ok()?;
-        Some(formatted_function_name)
+            .format_function(&name.to_string(), proc.type_index)
+            .ok()
     }
 
     fn get_procedure_lines(
@@ -550,7 +543,7 @@ impl<'a, 's, 't> Context<'a, 's, 't> {
     ) -> Result<Vec<CachedLineInfo>> {
         let lines_for_proc = line_program.lines_at_offset(proc.offset);
         let mut iterator = lines_for_proc.map(|line_info| {
-            let rva = line_info.offset.to_rva(&self.address_map).unwrap().0;
+            let rva = line_info.offset.to_rva(self.address_map).unwrap().0;
             Ok((rva, line_info))
         });
         let mut lines = Vec::new();
@@ -655,7 +648,7 @@ impl<'a, 's, 't> Context<'a, 's, 't> {
                     }
                     Some(l) => l,
                 };
-                let start_rva = line_info.offset.to_rva(&self.address_map).unwrap().0;
+                let start_rva = line_info.offset.to_rva(self.address_map).unwrap().0;
                 let end_rva = start_rva + length;
                 lines.push(InlineRange {
                     start_rva,
@@ -725,13 +718,9 @@ impl<'a, 's, 't> Context<'a, 's, 't> {
         let mut cache = self.inline_name_cache.borrow_mut();
         cache
             .entry(id_index)
-            .or_insert_with(|| {
-                let mut name = String::new();
-                let res = self.type_formatter.write_id(&mut name, id_index);
-                match res {
-                    Ok(()) => Some(Rc::new(name)),
-                    Err(_) => None,
-                }
+            .or_insert_with(|| match self.type_formatter.format_id(id_index) {
+                Ok(name) => Some(Rc::new(name)),
+                Err(_) => None,
             })
             .deref()
             .clone()
